==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/cmd/xtnulto.c <==
/*============================================================================*/
/* ѹ                                                                   */
/*----------------------------------------------------------------------------*/
/* 1.0 : APIб                                                      */
/*============================================================================*/

#include <musashi.h>
#include <stdlib.h>
#include <string.h>

#include <xtnultoHelp.h>
struct mssComHelp comHelp={
  "xtnulto",      /* ޥ̾       */
  "1.0",          /* С       */
  HELPT,          /* ޥɥȥ */                                    
  HELPS,          /*              */
  HELPE,          /*            */
  HELPR,          /* ȥޥ     */
  HELPA,          /* Ծ         */
  HELPB,          /* ХݡȾ */
  HELPH           /* ۡڡ     */
};

extern struct mssGlobalVariables mssGV;

int main(int argc, char *argv[]){
/*============================================================================*/
/* ץ                                                       */
/*============================================================================*//*----------------------------------------------------------------------------*/
/* оݹ                                                                   */
/*----------------------------------------------------------------------------*/
  MssOptFLD optFLD={
    OFLD,   /* ץ󥿥                                             */
    "f",    /* (ʣʸԲ)                                   */
    1,      /* 0:ץ, 1:ɬ, 2:XMLtableǤΤɬ(txtǤ̵)      */
    MssFieldMaxCnt, /* ǽʺܿ                                 */
    "i",    /* оݤȤϥǡΥ(GUI)                  */
    1,      /* ɽĤ뤫ɤ(0:Բ,1:)                      */
    1,      /* ̾Ǥ뤫ɤ(0:Բ,1:)                    */
    NULL,   /* ܥץ(%ʲ)ǻǽʸ                        */
            /* ex) ԲĤξNULL, "nr": "-f ̾%rn"λǽ     */
    FLDT,   /* ΥץΥȥ(Helpɽ)                         */
    FLDC,   /* ΥץΥ(Helpɽ)                         */
    FLDF    /* ե饰ˤĤƤ(Helpɽ)ʣξϥޤǶڤ   */
  };

/*----------------------------------------------------------------------------*/
/* ɲùܤ                                                               */
/*----------------------------------------------------------------------------*/
  MssOptSTR optVAL={
    OSTR,   /* ץ󥿥                                             */
    "v",    /* (ʣʸԲ)                                   */
    1,      /* 0:ץ, 1:ɬ, 2:XMLtableǤΤɬ(txtǤ̵)      */
    NULL  , /* ǥե                                                   */
    1,      /* ʸκǾĹ                                               */
    MssFieldMaxLen,/* ʸκĹ                                        */
    VALT,   /* ΥץΥȥ(Helpɽ)                         */
    VALC    /* ΥץΥ(Helpɽ)                         */
  };

/*----------------------------------------------------------------------------*/
/* ϥե                                                               */
/*----------------------------------------------------------------------------*/
  MssOptINF optINF={
    OINF,   /* ץ󥿥                                             */
    "i",    /* (ʣʸԲ)                                   */
    0,      /* 0:ץ, 1:ɬ                                         */
    1,      /* ǽκե                                     */
    0,      /*1:file not foundΥ顼ǽλʤ 0:                   */
    INFT,   /* ΥץΥȥ(Helpɽ)                         */
    INFC    /* ΥץΥ(Helpɽ)                         */
  };

/*----------------------------------------------------------------------------*/
/* ϥե                                                               */
/*----------------------------------------------------------------------------*/
  MssOptOTF optOTF={
    OOTF,   /* ץ󥿥                                             */
    "o",    /* (ʣʸԲ)                                   */
    0,      /* 0:ץ, 1:ɬ                                         */
    OTFT,   /* ΥץΥȥ(Helpɽ)                         */
    OTFC    /* ΥץΥ(Helpɽ)                         */
  };

/*----------------------------------------------------------------------------*/
/* ̽                                                                   */
/*----------------------------------------------------------------------------*/
  MssOptFLG optZIP={
    OFLG,   /* ץ󥿥                                             */
    "z",    /* (ʣʸԲ)                                   */
    0,      /* ǥե(Ūˤ0) onˤȤ1ˤ          */
    ZIPT,   /* ΥץΥȥ(Helpɽ)                         */
    ZIPC    /* ΥץΥ(Helpɽ)                         */
  };

/*----------------------------------------------------------------------------*/
/* plain text                                                                 */
/*----------------------------------------------------------------------------*/
  MssOptFLG optTXT={
    OFLG,   /* ץ󥿥                                             */
    "t",    /* (ʣʸԲ)                                   */
    0,      /* ǥե(Ūˤ0) onˤȤ1ˤ          */
    TXTT,   /* ΥץΥȥ(Helpɽ)                         */
    TXTC    /* ΥץΥ(Helpɽ)                         */
  };

/*----------------------------------------------------------------------------*/
/* ץޤȤ                                                       */
/*----------------------------------------------------------------------------*/
  void *opt[]={&optFLD,&optVAL,&optINF,&optOTF,&optZIP,&optTXT,NULL};

/*============================================================================*/
/* ѿ                                                             */
/*============================================================================*/
  struct mssHeader *hdi; /*ϥե<head>Ǽ¤*/
  struct mssHeader *hdo; /*ϥե<head>Ǽ¤*/
  struct mssFPR    *fpr; /*ϥե빽¤*/
  struct mssFPW    *fpw; /*ϥե빽¤*/
  struct mssFldRec *fr;  /*-ԥХåե¤*/
  int i;
  int num;

/*----------------------------------------------------------------------------*/
/*                                                                      */
/*----------------------------------------------------------------------------*/
  mssInit(argc,argv,&comHelp);       /* ʥʤɤν              */
  mssHelpDoc(opt,&comHelp,argc,argv);/* إ                                */
  mssSetOption(opt,argc,argv);       /* ޥɥץ              */
  fpr=mssOpenFPR(optINF.str,4);      /* ϥե륪ץ                  */
  hdi=mssReadHeader(fpr);            /* إåɤ߹                      */
  mssSetOptFld(&optFLD, hdi);        /* -f ܤإåܤ˴ϢŤ     */
      
  if(NULL!=strchr(optVAL.str,MssFieldDelim)){
    mssShowErrMsg("-v can not have a space character");
    mssEnd(mssErrorNoDefault);
  }

/*----------------------------------------------------------------------------*/
/*ϥإåκȽ                                                    */
/*----------------------------------------------------------------------------*/
  /*ϥإåν(ȥΥԡ)*/
  hdo=mssInitCpyHeader(hdi);

  /*-fǻꤵ줿ܤ-f顢¾ϥإåܤɲä*/
  mssAddHeadOrOptFields(hdo->flds,hdi,&optFLD);

  /*ɸϥץ+إåν*/
  fpw=mssOpenFPW(optOTF.str,optZIP.set,0);
  mssWriteHeader(hdo, fpw);

/*----------------------------------------------------------------------------*/
/*ᥤ롼                                                              */
/*----------------------------------------------------------------------------*/
  fr=mssInitFldRec(hdi->flds->cnt);
  while( EOF != mssReadFldRec(fpr,fr) ){
    mssGV.inCnt++;

    /*Խ񤭽Ф*/
    for(i=0; i<hdi->flds->cnt-1; i++){
      num=*(optFLD.fldNo2optNo+i);
      if(num==-1){
        mssWriteStr(*(fr->pnt+i), fpw);
        mssWriteDlm(fpw);
      }else{
        if( MssIsNull(*(fr->pnt+i)) ){
          mssWriteStr(optVAL.str, fpw);
        }else{
          mssWriteStr(*(fr->pnt+i), fpw);
        }
        mssWriteDlm(fpw);
      }
    }
      num=*(optFLD.fldNo2optNo+i);
      if(num==-1){
        mssWriteStr(*(fr->pnt+i), fpw);
        mssWriteRet(fpw);
      }else{
        if( MssIsNull(*(fr->pnt+i)) ){
          mssWriteStr(optVAL.str, fpw);
        }else{
          mssWriteStr(*(fr->pnt+i), fpw);
        }
        mssWriteRet(fpw);
      }
    mssGV.outCnt++;
  }
  mssFreeFldRec(fr);

/*----------------------------------------------------------------------------*/
/*եå&λ                                                       */
/*----------------------------------------------------------------------------*/
  mssWriteFooter(fpw);     /* եåν             */
  mssCloseFPR(fpr);        /* ϥեΥ     */
  mssCloseFPW(fpw);        /* ϥեΥ     */
  mssFreeHeader(hdi);      /* ϥإåΰ賫         */
  mssFreeHeader(hdo);      /* ϥإåΰ賫         */
  mssFreeOption(opt);      /* ץΰ賫         */
  mssShowEndMsg();         /* λå             */
  mssEnd(mssExitSuccess);  /* λ                       */
  return(0);               /* to avoid warning message   */
}

==> musashi-core-1.0.4-pre6.tar.gz: musashi-core-1.0.4-pre6/cmd/xtnulto.c <==
/*============================================================================*/
/* ѹ                                                                   */
/*----------------------------------------------------------------------------*/
/* 1.0 : APIб                                                      */
/* 1.1 : -O,-Aץɲ(2004/08/10)                                      */
/*============================================================================*/

#include <musashi.h>
#include <stdlib.h>
#include <string.h>

#include <xtnultoHelp.h>
struct mssComHelp comHelp={
  "xtnulto",      /* ޥ̾       */
  "1.1",          /* С       */
  HELPT,          /* ޥɥȥ */                                    
  HELPS,          /*              */
  HELPE,          /*            */
  HELPR,          /* ȥޥ     */
  HELPA,          /* Ծ         */
  HELPB,          /* ХݡȾ */
  HELPH           /* ۡڡ     */
};

extern struct mssGlobalVariables mssGV;

int main(int argc, char *argv[]){
/*============================================================================*/
/* ץ                                                       */
/*============================================================================*//*----------------------------------------------------------------------------*/
/* оݹ                                                                   */
/*----------------------------------------------------------------------------*/
  MssOptFLD optFLD={
    OFLD,   /* ץ󥿥                                             */
    "f",    /* (ʣʸԲ)                                   */
    1,      /* 0:ץ, 1:ɬ, 2:XMLtableǤΤɬ(txtǤ̵)      */
    MssFieldMaxCnt, /* ǽʺܿ                                 */
    "i",    /* оݤȤϥǡΥ(GUI)                  */
    1,      /* ɽĤ뤫ɤ(0:Բ,1:)                      */
    1,      /* ̾Ǥ뤫ɤ(0:Բ,1:)                    */
    NULL,   /* ܥץ(%ʲ)ǻǽʸ                        */
            /* ex) ԲĤξNULL, "nr": "-f ̾%rn"λǽ     */
    FLDT,   /* ΥץΥȥ(Helpɽ)                         */
    FLDC,   /* ΥץΥ(Helpɽ)                         */
    FLDF    /* ե饰ˤĤƤ(Helpɽ)ʣξϥޤǶڤ   */
  };

/*----------------------------------------------------------------------------*/
/* ɲùܤ                                                               */
/*----------------------------------------------------------------------------*/
  MssOptSTR optVAL={
    OSTR,   /* ץ󥿥                                             */
    "v",    /* (ʣʸԲ)                                   */
    1,      /* 0:ץ, 1:ɬ, 2:XMLtableǤΤɬ(txtǤ̵)      */
    NULL  , /* ǥե                                                   */
    1,      /* ʸκǾĹ                                               */
    MssFieldMaxLen,/* ʸκĹ                                        */
    VALT,   /* ΥץΥȥ(Helpɽ)                         */
    VALC    /* ΥץΥ(Helpɽ)                         */
  };

/*----------------------------------------------------------------------------*/
/* ִꥹȳִʸ                                                   */
/*----------------------------------------------------------------------------*/
  MssOptSTR optOTH={
    OSTR,   /* ץ󥿥                                             */
    "O",    /* (ʣʸԲ)                                   */
    0,      /* 0:ץ, 1:ɬ, 2:XMLtableǤΤɬ(txtǤ̵)      */
    NULL,   /* ǥե                                                   */
    1,      /* ʸκǾĹ                                               */
    MssFieldMaxLen,/* ʸκĹ                                        */
    OTHT,   /* ΥץΥȥ(Helpɽ)                         */
    OTHC    /* ΥץΥ(Helpɽ)                         */
  };

/*----------------------------------------------------------------------------*/
/* ܤȤƽϤ                                                   */
/*----------------------------------------------------------------------------*/
  MssOptFLG optNEW={
    OFLG,   /* ץ󥿥                                             */
    "A",    /* (ʣʸԲ)                                   */
    0,      /* ǥե(Ūˤ0) onˤȤ1ˤ          */
    NEWT,   /* ΥץΥȥ(Helpɽ)                         */
    NEWC    /* ΥץΥ(Helpɽ)                         */
  };

/*----------------------------------------------------------------------------*/
/* ϥե                                                               */
/*----------------------------------------------------------------------------*/
  MssOptINF optINF={
    OINF,   /* ץ󥿥                                             */
    "i",    /* (ʣʸԲ)                                   */
    0,      /* 0:ץ, 1:ɬ                                         */
    1,      /* ǽκե                                     */
    0,      /*1:file not foundΥ顼ǽλʤ 0:                   */
    INFT,   /* ΥץΥȥ(Helpɽ)                         */
    INFC    /* ΥץΥ(Helpɽ)                         */
  };

/*----------------------------------------------------------------------------*/
/* ϥե                                                               */
/*----------------------------------------------------------------------------*/
  MssOptOTF optOTF={
    OOTF,   /* ץ󥿥                                             */
    "o",    /* (ʣʸԲ)                                   */
    0,      /* 0:ץ, 1:ɬ                                         */
    OTFT,   /* ΥץΥȥ(Helpɽ)                         */
    OTFC    /* ΥץΥ(Helpɽ)                         */
  };

/*----------------------------------------------------------------------------*/
/* ̽                                                                   */
/*----------------------------------------------------------------------------*/
  MssOptFLG optZIP={
    OFLG,   /* ץ󥿥                                             */
    "z",    /* (ʣʸԲ)                                   */
    0,      /* ǥե(Ūˤ0) onˤȤ1ˤ          */
    ZIPT,   /* ΥץΥȥ(Helpɽ)                         */
    ZIPC    /* ΥץΥ(Helpɽ)                         */
  };

/*----------------------------------------------------------------------------*/
/* plain text                                                                 */
/*----------------------------------------------------------------------------*/
  MssOptFLG optTXT={
    OFLG,   /* ץ󥿥                                             */
    "t",    /* (ʣʸԲ)                                   */
    0,      /* ǥե(Ūˤ0) onˤȤ1ˤ          */
    TXTT,   /* ΥץΥȥ(Helpɽ)                         */
    TXTC    /* ΥץΥ(Helpɽ)                         */
  };

/*----------------------------------------------------------------------------*/
/* ץޤȤ                                                       */
/*----------------------------------------------------------------------------*/
  void *opt[]={&optFLD,&optVAL,&optOTH,&optNEW,&optINF,&optOTF,&optZIP,&optTXT,NULL};

/*============================================================================*/
/* ѿ                                                             */
/*============================================================================*/
  struct mssHeader *hdi; /*ϥե<head>Ǽ¤*/
  struct mssHeader *hdo; /*ϥե<head>Ǽ¤*/
  struct mssFPR    *fpr; /*ϥե빽¤*/
  struct mssFPW    *fpw; /*ϥե빽¤*/
  struct mssFldRec *fr;  /*-ԥХåե¤*/
  int i;
  int num;

/*----------------------------------------------------------------------------*/
/*                                                                      */
/*----------------------------------------------------------------------------*/
  mssInit(argc,argv,&comHelp);       /* ʥʤɤν              */
  mssHelpDoc(opt,&comHelp,argc,argv);/* إ                                */
  mssSetOption(opt,argc,argv);       /* ޥɥץ              */
  fpr=mssOpenFPR(optINF.str,4);      /* ϥե륪ץ                  */
  hdi=mssReadHeader(fpr);            /* إåɤ߹                      */
  mssSetOptFld(&optFLD, hdi);        /* -f ܤإåܤ˴ϢŤ     */
      
  if(NULL!=strchr(optVAL.str,MssFieldDelim)){
    mssShowErrMsg("-v can not have a space character");
    mssEnd(mssErrorNoDefault);
  }

  if(optOTH.set){
    if(NULL!=strchr(optOTH.str,MssFieldDelim)){
      mssShowErrMsg("-O can not have a space character");
      mssEnd(mssErrorNoDefault);
    }
  }

/*----------------------------------------------------------------------------*/
/*ϥإåκȽ                                                    */
/*----------------------------------------------------------------------------*/
  /*ϥإåν(ȥΥԡ)*/
  hdo=mssInitCpyHeader(hdi);

  /*̾ɲä*/
  if(optNEW.set){
    mssAddFieldsByFields(hdo->flds,hdi->flds);                                
    mssAddFieldsByStrList(hdo->flds,optFLD.newNam,optFLD.cnt);
    
  /*-fǻꤵ줿ܤ-f顢¾ϥإåܤɲä*/
  }else{
    mssAddHeadOrOptFields(hdo->flds,hdi,&optFLD);
  } 

  /*ɸϥץ+إåν*/
  fpw=mssOpenFPW(optOTF.str,optZIP.set,0);
  mssWriteHeader(hdo, fpw);

/*----------------------------------------------------------------------------*/
/*ᥤ롼                                                              */
/*----------------------------------------------------------------------------*/
  fr=mssInitFldRec(hdi->flds->cnt);
  while( EOF != mssReadFldRec(fpr,fr) ){
    mssGV.inCnt++;

    /*ɲäξ*/
    if(optNEW.set){
      mssWriteFld(fr->pnt,fr->fldCnt,"",fpw);
      for(i=0; i<optFLD.flds->cnt; i++){
        if( MssIsNull(*(fr->pnt+MssFlds2num(optFLD.flds,i))) ){  /* NULL!! */
          mssWriteDlm(fpw);
          mssWriteStr(optVAL.str, fpw);
        }else{                                                /* NULLͤǤʤ */
          mssWriteDlm(fpw);
          if(optOTH.set) mssWriteStr(optOTH.str,   fpw);
          else           mssWriteStr(*(fr->pnt+MssFlds2num(optFLD.flds,i)),fpw);
        }
      }
      mssWriteRet(fpw);

    /*ִξ*/
    }else{

      /*Խ񤭽Ф*/
      for(i=0; i<hdi->flds->cnt; i++){
        num=*(optFLD.fldNo2optNo+i);
        if(num==-1){ /* -f ǻꤵ줿ܤǤʤ */
          mssWriteStr(*(fr->pnt+i), fpw);
          if(i==hdi->flds->cnt-1) mssWriteRet(fpw);
          else                    mssWriteDlm(fpw);
        }else{       /* -f ǻꤵ줿ܤξ */
          if( MssIsNull(*(fr->pnt+i)) ){  /* NULL!! */
            mssWriteStr(optVAL.str, fpw);
          }else{                          /* NULLͤǤʤ */
            if(optOTH.set) mssWriteStr(optOTH.str,   fpw);
            else           mssWriteStr(*(fr->pnt+i), fpw);
          }
          if(i==hdi->flds->cnt-1) mssWriteRet(fpw);
          else                    mssWriteDlm(fpw);
        }
      }
    }

    mssGV.outCnt++;
  }
  mssFreeFldRec(fr);

/*----------------------------------------------------------------------------*/
/*եå&λ                                                       */
/*----------------------------------------------------------------------------*/
  mssWriteFooter(fpw);     /* եåν             */
  mssCloseFPR(fpr);        /* ϥեΥ     */
  mssCloseFPW(fpw);        /* ϥեΥ     */
  mssFreeHeader(hdi);      /* ϥإåΰ賫         */
  mssFreeHeader(hdo);      /* ϥإåΰ賫         */
  mssFreeOption(opt);      /* ץΰ賫         */
  mssShowEndMsg();         /* λå             */
  mssEnd(mssExitSuccess);  /* λ                       */
  return(0);               /* to avoid warning message   */
}
